@@ -22,6 +22,8 @@ class BaseFunctions(SalureConnect):
         super().__init__()
         credentials = self.get_system_credential(system='sap', label=label)
         self.label = label
+        self.credentials = credentials
+        self.key_file = key_file
         self.base_url = credentials['base_url']
         self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], certificate_file, key_file, credentials['client_secret'])
         self.data_dir = data_dir
@@ -63,7 +65,7 @@ class BaseFunctions(SalureConnect):
         response = requests.request("GET", f"{url}", headers=self.headers, data={})
         if response.status_code == 401:
             credentials = self.get_system_credential(system='sap', label=self.label)
-            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], certificate_file, key_file, credentials['client_secret'])
+            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], self.certificate_file, self.key_file, credentials['client_secret'])
         if self.debug:
             print(response.text)
         if response.status_code >= 300:
@@ -105,7 +107,7 @@ class BaseFunctions(SalureConnect):
             return response
         if response.status_code == 401:
             credentials = self.get_system_credential(system='sap', label=self.label)
-            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], certificate_file, key_file, credentials['client_secret'])
+            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], self.certificate_file, self.key_file, credentials['client_secret'])
         # Don't use raise_for_status() here because the errors from SAP will come in XML format which can be parsed here
         if response.status_code == 201:
             if len(response.text) == 0 or return_key is None:
@@ -140,7 +142,7 @@ class BaseFunctions(SalureConnect):
         response = requests.request("DELETE", f"{url}", headers=self.headers)
         if response.status_code == 401:
             credentials = self.get_system_credential(system='sap', label=self.label)
-            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], certificate_file, key_file, credentials['client_secret'])
+            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], self.certificate_file, self.key_file, credentials['client_secret'])
         return response
 
     def exclude_expired_objects(self, df, col='end_date', expiration_date=datetime.datetime.today()):
